==> mod_uploader-1.1.2.tgz: mod_uploader-1.1.2/src/PostReader.cpp <==
/******************************************************************************
 * mod_uploader / PostReader.cpp
 ******************************************************************************
 * Copyright (C) 2005 Tetsuya Kimata <kimata@acapulco.dyndns.org>
 *
 * All rights reserved.
 *
 * This software is provided 'as-is', without any express or implied
 * warranty.  In no event will the authors be held liable for any
 * damages arising from the use of this software.
 *
 * Permission is granted to anyone to use this software for any
 * purpose, including commercial applications, and to alter it and
 * redistribute it freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must
 *    not claim that you wrote the original software. If you use this
 *    software in a product, an acknowledgment in the product
 *    documentation would be appreciated but is not required.
 *
 * 2. Altered source versions must be plainly marked as such, and must
 *    not be misrepresented as being the original software.
 *
 * 3. This notice may not be removed or altered from any source
 *    distribution.
 *
 * $Id: PostReader.cpp 540 2005-08-31 11:27:51Z svn $
 *****************************************************************************/

#include "PostReader.h"

#ifdef DEBUG
#include <iostream>
#endif


/******************************************************************************
 * public ᥽å
 *****************************************************************************/
PostReader::PostReader(apr_size_t block_size)
    : block_size_(block_size)
{

}

PostReader::~PostReader()
{

}


/******************************************************************************
 * protected ᥽å
 *****************************************************************************/
apr_size_t PostReader::get_block_size()
{
    return block_size_;
}


// Local Variables:
// mode: c++
// buffer-file-coding-system: euc-japan-dos
// End:

==> mod_uploader-1.2.0.tgz: mod_uploader-1.2.0/src/PostReader.cpp <==
/******************************************************************************
 * mod_uploader / PostReader.cpp
 ******************************************************************************
 * Copyright (C) 2005 Tetsuya Kimata <kimata@acapulco.dyndns.org>
 *
 * All rights reserved.
 *
 * This software is provided 'as-is', without any express or implied
 * warranty.  In no event will the authors be held liable for any
 * damages arising from the use of this software.
 *
 * Permission is granted to anyone to use this software for any
 * purpose, including commercial applications, and to alter it and
 * redistribute it freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must
 *    not claim that you wrote the original software. If you use this
 *    software in a product, an acknowledgment in the product
 *    documentation would be appreciated but is not required.
 *
 * 2. Altered source versions must be plainly marked as such, and must
 *    not be misrepresented as being the original software.
 *
 * 3. This notice may not be removed or altered from any source
 *    distribution.
 *
 * $Id: PostReader.cpp 638 2005-09-07 21:51:26Z svn $
 *****************************************************************************/

#include "PostReader.h"

#ifdef DEBUG
#include <iostream>
#endif


/******************************************************************************
 * public ᥽å
 *****************************************************************************/
PostReader::PostReader(apr_size_t block_size, progress *progress)
    : block_size_(block_size),
      progress_(progress)
{

}

PostReader::~PostReader()
{

}


/******************************************************************************
 * protected ᥽å
 *****************************************************************************/
void PostReader::update(apr_size_t read_size)
{
    progress_->read_size += read_size;
}

apr_size_t PostReader::get_block_size()
{
    return block_size_;
}


// Local Variables:
// mode: c++
// buffer-file-coding-system: euc-japan-dos
// End:
